AppsFlyerDestination class

Inheritance
  • Object
  • Plugin
  • EventPlugin
  • DestinationPlugin
  • AppsFlyerDestination

Constructors

AppsFlyerDestination()

Properties

analytics → Analytics?
no setterinherited
appsFlyer ↔ AppsflyerSdk?
getter/setter pair
appsFlyerSettings ↔ AppsFlyerSettings?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasInitialized ↔ bool
getter/setter pair
hasRegisteredDeepLinkCallback ↔ bool
getter/setter pair
hasRegisteredInstallCallback ↔ bool
getter/setter pair
key → String
finalinherited
pAnalytics ↔ Analytics?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline ↔ Timeline
getter/setter pairinherited
type → PluginType
finalinherited

Methods

add(Plugin plugin) → Plugin
Adds a new plugin to the currently loaded set.
inherited
alias(AliasEvent event) → Future<RawEvent?>
inherited
apply(PluginClosure closure) → void
Applies the supplied closure to the currently loaded set of plugins.
inherited
clear() → void
inherited
configure(Analytics analytics) → void
inherited
execute(RawEvent event) → Future<RawEvent?>
inherited
flush() → Future
inherited
group(GroupEvent event) → Future<RawEvent?>
inherited
identify(IdentifyEvent event) → Future<RawEvent?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(RawEvent event) → Future<RawEvent?>
inherited
registerConversionCallback() → void
registerDeepLinkCallback() → void
remove(Plugin plugin) → void
Removes and unloads plugins with a matching name from the system. Parameter pluginName: An plugin name.
inherited
reset() → void
inherited
screen(ScreenEvent event) → Future<RawEvent?>
inherited
shutdown() → void
inherited
toString() → String
A string representation of this object.
inherited
track(TrackEvent event) → Future<RawEvent?>
override
update(Map<String, dynamic> settings, ContextUpdateType type) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited